@@ -1,8 +1,8 @@
+from django_audit_fields.admin import ModelAdminAuditFieldsMixin
 from django_revision.modeladmin_mixin import ModelAdminRevisionMixin
 from edc_notification import NotificationModelAdminMixin
 
-from edc_model_admin import (
-    ModelAdminAuditFieldsMixin,
+from edc_model_admin.mixins import (
     ModelAdminFormAutoNumberMixin,
     ModelAdminFormInstructionsMixin,
     ModelAdminInstitutionMixin,
